==> SimplyDualWielding-4.5.0%2B1.21.4-Fabric-sources.jar: eva/dualwielding/config/SimplyDualWieldingConfig.java <==
package eva.dualwielding.config;

import eva.dualwielding.network.ConfigPayload;
import eva.dualwielding.network.ListPayload;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class SimplyDualWieldingConfig {

    private boolean empty = false;
    private ItemCat attacks = ItemCat.ALL;
    private ItemCat mines = ItemCat.ALL;
    private List<String> attackList = new ArrayList<>();
    private List<String> mineList = new ArrayList<>();
    private boolean[] allowWeakConfig = {false, false, false, false};
    private boolean respectIMMining = true;
    private boolean respectIMAttacking = true;
    private ConditionalBehavior restrictUse = ConditionalBehavior.SNEAKING_ONLY;
    private List<String> disableUseList;

    private static SimplyDualWieldingConfig INSTANCE;
    private static SimplyDualWieldingConfig SERVER_INSTANCE;
    private static final boolean[] readSinceLastUpdate = {false, false, false, false, false, false, false, false, false};
    private static final List<String> def = new ArrayList<>();
    static {def.add("minecraft:air");}
    private static final List<String> defUseList = new ArrayList<>();
    static {
        defUseList.add("minecraft:wooden_axe");
        defUseList.add("minecraft:stone_axe");
        defUseList.add("minecraft:iron_axe");
        defUseList.add("minecraft:golden_axe");
        defUseList.add("minecraft:diamond_axe");
        defUseList.add("minecraft:netherite_axe");
        defUseList.add("minecraft:wooden_shovel");
        defUseList.add("minecraft:stone_shovel");
        defUseList.add("minecraft:iron_shovel");
        defUseList.add("minecraft:golden_shovel");
        defUseList.add("minecraft:diamond_shovel");
        defUseList.add("minecraft:netherite_shovel");
        defUseList.add("minecraft:wooden_hoe");
        defUseList.add("minecraft:stone_hoe");
        defUseList.add("minecraft:iron_hoe");
        defUseList.add("minecraft:golden_hoe");
        defUseList.add("minecraft:diamond_hoe");
        defUseList.add("minecraft:netherite_hoe");
    }
    private static ListState listState = ListState.ATTACK;

    private SimplyDualWieldingConfig() {
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public SimplyDualWieldingConfig(boolean empty, ItemCat attacks, ItemCat mines, ConditionalBehavior restrictUse, boolean[] allowWeakConfig) {
        this.empty = empty;
        this.attacks = attacks;
        this.mines = mines;
        this.restrictUse = restrictUse;
        this.allowWeakConfig = allowWeakConfig;
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public static SimplyDualWieldingConfig getInstance() {
        if (INSTANCE == null) {
            INSTANCE = new SimplyDualWieldingConfig();
        }
        return INSTANCE;
    }

    public static SimplyDualWieldingConfig getServerInstance() {
        return SERVER_INSTANCE;
    }

    private static void setServerInstance(SimplyDualWieldingConfig newInstance) {
        SERVER_INSTANCE = newInstance;
    }

    public void updateConfigs(SimplyDualWieldingConfig config) {
        this.empty = config.empty;
        this.attacks = config.attacks;
        this.mines = config.mines;
        setAttackItems(config.attackList);
        setMineItems(config.mineList);
    }

    static void setEmpty(boolean setter) {
        readSinceLastUpdate[0] = false;
        getInstance().empty = setter;
    }
    public boolean getEmpty() {
        readSinceLastUpdate[0] = true;
        return this.empty;
    }

    static void setRestrictUse(ConditionalBehavior setter) {
        readSinceLastUpdate[7] = false;
        getInstance().restrictUse = setter;
    }
    public ConditionalBehavior getRestrictUse() {
        readSinceLastUpdate[7] = true;
        return this.restrictUse;
    }

    static void setAttacks(ItemCat setter) {
        readSinceLastUpdate[1] = false;
        getInstance().attacks = setter;
    }
    public ItemCat getAttacks() {
        readSinceLastUpdate[1] = true;
        return this.attacks;
    }

    static void setMines(ItemCat setter) {
        readSinceLastUpdate[2] = false;
        getInstance().mines = setter;
    }
    public ItemCat getMines() {
        readSinceLastUpdate[2] = true;
        return this.mines;
    }

    public List<String> getAttackItems() {
        readSinceLastUpdate[3] = true;
        return this.attackList;
    }
    static void setAttackItems(List<String> newList) {
        readSinceLastUpdate[3] = false;
        getInstance().attackList = newList;
    }

    public List<String> getMineItems() {
        readSinceLastUpdate[4] = true;
        return this.mineList;
    }
    static void setMineItems(List<String> newList) {
        readSinceLastUpdate[4] = false;
        getInstance().mineList = newList;
    }

    public List<String> getDisableUseItems() {
        readSinceLastUpdate[8] = true;
        return this.disableUseList;
    }
    static void setDisableUseItems(List<String> newList) {
        readSinceLastUpdate[8] = false;
        getInstance().disableUseList = newList;
    }

    public boolean getRespectIMAttacking() {
        readSinceLastUpdate[5] = true;
        return this.respectIMAttacking;
    }

    static void setRespectIMAttacking(boolean newVal) {
        readSinceLastUpdate[5] = false;
        getInstance().respectIMAttacking = newVal;
    }

    public boolean getRespectIMMining() {
        readSinceLastUpdate[6] = true;
        return this.respectIMMining;
    }

    static void setRespectIMMining(boolean newVal) {
        readSinceLastUpdate[6] = false;
        getInstance().respectIMMining = newVal;
    }

    public static Set<class_2960> getSetFromList (List<String> list) {
        Set<class_2960> set = ConcurrentHashMap.newKeySet();
        for (String nam : list)
            set.add(class_2960.method_60654(nam));
        return set;
    }

    public static boolean getReadStatus(int i) {
        return readSinceLastUpdate[i];
    }

    public static void onConfigReceived(ConfigPayload payload) {
        setServerInstance(payload.getHeldInstance());
    }

    public static void onListReceived(ListPayload listPayload) {
        List<String> list = listPayload.getList();
        for (String entry : list) {
            switch (listState) {
                case ATTACK:
                    if (entry.isEmpty())
                        listState = ListState.MINE;
                    else
                        SERVER_INSTANCE.attackList.add(entry);
                    break;
                case MINE:
                    if (entry.isEmpty())
                        listState = ListState.USE_DISABLED;
                    else
                        SERVER_INSTANCE.mineList.add(entry);
                case USE_DISABLED:
                    if (entry.isEmpty())
                        listState = ListState.ATTACK;
                    else
                        SERVER_INSTANCE.mineList.add(entry);
            }
        }
    }


    private static class ErrorSupplier implements Function<String, Optional<class_2561>> {
        @Override
        public Optional<class_2561> apply(String entry) {
            entry = entry.toLowerCase();
            if (entry.indexOf(':') != entry.lastIndexOf(':'))
                return Optional.of(class_2561.method_43470("Enter a valid item ID! error code: 1"));
            String name = entry.substring(entry.indexOf(':') + 1).replaceAll("[^a-z0-9/._-]", "");
            if (!entry.equals(name)) {
                if (entry.indexOf(':') == -1)
                    return Optional.of(class_2561.method_43470("Enter a valid item ID! error code: 2"));
                String namespace = entry.substring(0,entry.indexOf(':')).replaceAll("[^a-z0-9/._-]", "");
                if (!entry.equals(namespace + ":" + name)) {
                    return Optional.of(class_2561.method_43470("Enter a valid item ID! error code: 3"));
                }
            }
            class_2960 id = class_2960.method_60654(entry);
            if (!class_7923.field_41178.method_10235().contains(id))
                return Optional.of(class_2561.method_43470("Enter a valid item ID! error code: 4"));
            return Optional.empty();
        }
    }
    static Function<String, Optional<class_2561>> getErrorSupplier() {
        return new ErrorSupplier();
    }

    static List<String> getDef() {
        return def;
    }

    static List<String> getDefUseList() {return defUseList;}

    public boolean[] getAllowWeakConfig() {
        return this.allowWeakConfig;
    }

    public boolean getAllowWeakConfig(int i) {
        return this.allowWeakConfig[i];
    }

    public static void disconnect() {
        if (SERVER_INSTANCE != null)
            SERVER_INSTANCE = null;
    }

    private enum ListState {
        ATTACK,
        MINE,
        USE_DISABLED
    }

}

==> SimplyDualWielding-6.0.5%2B1.20.1-Fabric-sources.jar: eva/dualwielding/config/SimplyDualWieldingConfig.java <==
package eva.dualwielding.config;

import eva.dualwielding.config.enums.BalanceMode;
import eva.dualwielding.config.enums.ConditionalBehavior;
import eva.dualwielding.config.enums.ItemCat;
import eva.dualwielding.network.BalancePacket;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class SimplyDualWieldingConfig {

    private boolean empty = false;
    private ItemCat attacks = ItemCat.ALL;
    private ItemCat mines = ItemCat.ALL;
    private List<String> attackList;
    private List<String> mineList;
    private List<String> disableUseList;
    private boolean[] allowWeakConfig = {false, false, false, false};
    private boolean respectIMMining = true;
    private boolean respectIMAttacking = true;
    private ConditionalBehavior restrictUse = ConditionalBehavior.SNEAKING_ONLY;
    private BalanceMode mode = BalanceMode.PRETTY_MUCH_BALANCED;
    private double dualFactor = 0.7;
    private double twoHandedFactor = 1.4;
    private double oneHandedFactor = 1.0;

    private static SimplyDualWieldingConfig INSTANCE;
    private static SimplyDualWieldingConfig SERVER_INSTANCE;
    private static final List<String> def = new ArrayList<>();
    static {def.add("minecraft:air");}
    private static final List<String> defUseList = new ArrayList<>();
    static {
        defUseList.add("minecraft:wooden_axe");
        defUseList.add("minecraft:stone_axe");
        defUseList.add("minecraft:iron_axe");
        defUseList.add("minecraft:golden_axe");
        defUseList.add("minecraft:diamond_axe");
        defUseList.add("minecraft:netherite_axe");
        defUseList.add("minecraft:wooden_shovel");
        defUseList.add("minecraft:stone_shovel");
        defUseList.add("minecraft:iron_shovel");
        defUseList.add("minecraft:golden_shovel");
        defUseList.add("minecraft:diamond_shovel");
        defUseList.add("minecraft:netherite_shovel");
        defUseList.add("minecraft:wooden_hoe");
        defUseList.add("minecraft:stone_hoe");
        defUseList.add("minecraft:iron_hoe");
        defUseList.add("minecraft:golden_hoe");
        defUseList.add("minecraft:diamond_hoe");
        defUseList.add("minecraft:netherite_hoe");
    }
    private static ListState listState = ListState.ATTACK;

    private SimplyDualWieldingConfig() {
        attackList = def;
        mineList = def;
        disableUseList = defUseList;
    }

    public SimplyDualWieldingConfig(boolean empty, ItemCat attacks, ItemCat mines, ConditionalBehavior restrictUse, boolean[] allowWeakConfig, BalanceMode mode) {
        this.empty = empty;
        this.attacks = attacks;
        this.mines = mines;
        this.restrictUse = restrictUse;
        this.allowWeakConfig = allowWeakConfig;
        this.attackList = def;
        this.mineList = def;
        this.disableUseList = defUseList;
        this.mode = mode;
    }

    public static SimplyDualWieldingConfig getInstance() {
        if (INSTANCE == null) {
            INSTANCE = new SimplyDualWieldingConfig();
        }
        return INSTANCE;
    }

    public static SimplyDualWieldingConfig getServerInstance() {
        return SERVER_INSTANCE;
    }

    private static void setServerInstance(SimplyDualWieldingConfig newInstance) {
        SERVER_INSTANCE = newInstance;
    }

    public void updateConfigs(SimplyDualWieldingConfig config) {
        this.empty = config.empty;
        this.attacks = config.attacks;
        this.mines = config.mines;
        this.restrictUse = config.restrictUse;
        setAttackItems(config.attackList);
        setMineItems(config.mineList);
        setDisableUseItems(config.disableUseList);
        this.allowWeakConfig = config.allowWeakConfig;
        this.respectIMMining = config.respectIMMining;
        this.respectIMAttacking = config.respectIMAttacking;
        this.mode = config.mode;
        this.dualFactor = config.dualFactor;
        this.twoHandedFactor = config.twoHandedFactor;
        this.oneHandedFactor = config.oneHandedFactor;
    }

    static void setEmpty(boolean setter) {
        getInstance().empty = setter;
    }
    public boolean getEmpty() {
        return this.empty;
    }

    static void setRestrictUse(ConditionalBehavior setter) {
        getInstance().restrictUse = setter;
    }
    public ConditionalBehavior getRestrictUse() {
        return this.restrictUse;
    }

    static void setAttacks(ItemCat setter) {
        getInstance().attacks = setter;
    }
    public ItemCat getAttacks() {
        return this.attacks;
    }

    static void setMines(ItemCat setter) {
        getInstance().mines = setter;
    }
    public ItemCat getMines() {
        return this.mines;
    }

    public List<String> getAttackItems() {
        return this.attackList;
    }
    static void setAttackItems(List<String> newList) {
        getInstance().attackList = newList;
    }

    public List<String> getMineItems() {
        return this.mineList;
    }
    static void setMineItems(List<String> newList) {
        getInstance().mineList = newList;
    }

    public List<String> getDisableUseItems() {
        return this.disableUseList;
    }
    static void setDisableUseItems(List<String> newList) {
        getInstance().disableUseList = newList;
    }

    public boolean getRespectIMAttacking() {
        return this.respectIMAttacking;
    }

    static void setRespectIMAttacking(boolean newVal) {
        getInstance().respectIMAttacking = newVal;
    }

    public boolean getRespectIMMining() {
        return this.respectIMMining;
    }

    static void setRespectIMMining(boolean newVal) {
        getInstance().respectIMMining = newVal;
    }

    public BalanceMode getMode() {
        return mode;
    }
    public static void setMode(BalanceMode mode) {
        getInstance().mode = mode;
    }

    public double getDualFactor() {
        return dualFactor;
    }
    public static void setDualFactor(double dualFactor) {
        getInstance().dualFactor = dualFactor;
    }

    public double getTwoHandedFactor() {
        return twoHandedFactor;
    }
    public static void setTwoHandedFactor(double twoHandedFactor) {
        getInstance().twoHandedFactor = twoHandedFactor;
    }

    public double getOneHandedFactor() {
        return oneHandedFactor;
    }
    public static void setOneHandedFactor(double oneHandedFactor) {
        getInstance().oneHandedFactor = oneHandedFactor;
    }

    public double[] getValues() {
        return new double[]{dualFactor, oneHandedFactor, twoHandedFactor};
    }

    public static void onBalanceReceived(BalancePacket payload) {
        double[] values = payload.getValues();
        SERVER_INSTANCE.dualFactor = values[0];
        SERVER_INSTANCE.oneHandedFactor  = values[1];
        SERVER_INSTANCE.twoHandedFactor  = values[2];
    }

    public static Set<class_2960> getSetFromList (List<String> list) {
        Set<class_2960> set = ConcurrentHashMap.newKeySet();
        for (String nam : list)
            set.add(class_2960.method_12829(nam));
        return set;
    }

    public static void onConfigReceived(ConfigPacket payload) {
        setServerInstance(payload.getHeldInstance());
    }

    public static void onListReceived(ListPacket listPacket) {
        List<String> list = listPacket.getList();
        for (String entry : list) {
            switch (listState) {
                case ATTACK:
                    if (entry.isEmpty())
                        listState = ListState.MINE;
                    else
                        SERVER_INSTANCE.attackList.add(entry);
                    break;
                case MINE:
                    if (entry.isEmpty())
                        listState = ListState.USE_DISABLED;
                    else
                        SERVER_INSTANCE.mineList.add(entry);
                    break;
                case USE_DISABLED:
                    if (entry.isEmpty())
                        listState = ListState.ATTACK;
                    else
                        if (entry.equals("def"))
                            SERVER_INSTANCE.disableUseList.addAll(defUseList);
                        else
                            SERVER_INSTANCE.disableUseList.add(entry);

            }
        }
    }

    private static class ErrorSupplier implements Function<String, Optional<class_2561>> {
        @Override
        public Optional<class_2561> apply(String entry) {
            entry = entry.toLowerCase();
            if (entry.indexOf(':') != entry.lastIndexOf(':'))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 1"));
            String name = entry.substring(entry.indexOf(':') + 1).replaceAll("[^a-z0-9/._-]", "");
            if (!entry.equals(name)) {
                if (entry.indexOf(':') == -1)
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 2"));
                String namespace = entry.substring(0,entry.indexOf(':')).replaceAll("[^a-z0-9/._-]", "");
                if (!entry.equals(namespace + ":" + name)) {
                    return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 3"));
                }
            }
            class_2960 id = class_2960.method_12829(entry);
            if (!class_7923.field_41178.method_10235().contains(id))
                return Optional.of(class_2561.method_43470("Enter a valid item TYPE! error code: 4"));
            return Optional.empty();
        }
    }
    static Function<String, Optional<class_2561>> getErrorSupplier() {
        return new ErrorSupplier();
    }

    static List<String> getDef() {
        return def;
    }

    public static List<String> getDefUseList() {return defUseList;}

    public boolean[] getAllowWeakConfig() {
        return this.allowWeakConfig;
    }

    public boolean getAllowWeakConfig(int i) {
        return this.allowWeakConfig[i];
    }

    public static void disconnect() {
        if (SERVER_INSTANCE != null)
            SERVER_INSTANCE = null;
    }

    private enum ListState {
        ATTACK,
        MINE,
        USE_DISABLED
    }

}
